==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetTemplateThemeModels.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- exec [GetTemplateThemeModels] 'allegro','Test1234'
CREATE PROCEDURE [dbo].[GetTemplateThemeModels] (
	@VCC Varchar(50) = NULL, 
	@TemplateId Varchar(50) = NULL,
	@TemplateThemeId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DETERMINAR SI ES UN FORMATO O PLANTILLA
	DECLARE @TEMPLATE_TYPE VARCHAR(50) = NULL

	-- BUSCAMOS POR EL ID SI SE TRATA DE UNA PLANTILLA O FORMATO
	IF EXISTS (
		SELECT 1 
			FROM [dbo].[Template] T (NOLOCK)
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = T.[VCC]
					AND EF.[templateId] = T.[Name]
			WHERE T.[VCC] = @VCC
				AND T.[Name] = @TemplateId
	)
		SET @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	ELSE 
		SET @TEMPLATE_TYPE = 'TEMPLATE'

	-- SELECCIONAMOS LOS ITEMS INMEDIATOS RELACIONADOS AL TEMPLATE
	SELECT DISTINCT A.[VCC]												'vcc',	
					A.[TemplateId]										'templateId',
					A.[TemplateThemeId]									'templateThemeId',
					A.[ID]												'id',
					-- CASE WHEN ISNULL(GQ.[Query],'') = ISNULL(NULL,'') THEN A.[ID] ELSE GQ.[Query] END	'query',
					--A.[ID]												'query',
					CASE WHEN @TEMPLATE_TYPE = 'EVALUATION_FORMAT' 
						THEN A.[ID]
						ELSE 
							CASE WHEN NI.[nluId] IS NOT NULL 
								THEN NI.[nluId] + '|' + NI.[intentId]
								ELSE A.[ID]
								END
						END												'query',
					TT.[AnalysisType]									'analysisType',
					@TEMPLATE_TYPE										'templateType',
					A.[AcceptancePercentage]							'acceptancePercentage',
					ISNULL(A.[AcceptancePercentage],0) * 100			'acceptanceInteger',
					A.[CreatedDate]										'createdDate',
					A.[CreatedByUserId]									'createdByUserId',
					A.[LastModifiedDate]								'lastModifiedDate',
					A.[LastModifiedByUserId]							'lastModifiedByUserId'
		INTO #TEMPLATE_MODELS 
		FROM [TemplateThemeItem] A (NOLOCK)
		INNER JOIN [dbo].[TemplateTheme] TT (NOLOCK)
			ON TT.[VCC] = A.[VCC]
				AND TT.[TemplateId] = A.[TemplateId]
				AND TT.[ID] = A.[TemplateThemeId]
		LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
			ON A.[ID] = GQ.[Name] 
				AND A.[VCC] = GQ.[VCC]
		LEFT JOIN (
			SELECT DISTINCT
					INNER_N.[VCC]								'vcc'
					,INNER_N.[Name] + '|'+ INNER_I.[Name]		'cognitiveId'
					,INNER_N.[Name]								'nluId'
					,INNER_N.[AppId]							'appId'
					,INNER_I.[IntentId]							'intentId'
					,INNER_I.[Name]
				FROM [dbo].[NLU] INNER_N (NOLOCK)
				INNER JOIN [dbo].[Intent] INNER_I (NOLOCK) 
					ON INNER_N.[VCC] = INNER_I.[VCC]
						AND INNER_N.AppId = INNER_I.[AppId] 
				WHERE INNER_N.[VCC] = @VCC
		) NI 
			ON NI.[vcc] = A.[VCC]
				AND NI.[cognitiveId] = A.[ID]
		WHERE A.[VCC] = @VCC
			AND A.[TemplateId] = CASE WHEN ISNULL(@TemplateId, '') = '' THEN A.[TemplateId] ELSE @TemplateId END
			AND A.[TemplateThemeId] = CASE WHEN ISNULL(@TemplateThemeId, '') = '' THEN A.[TemplateThemeId] ELSE @TemplateThemeId END
			AND GQ.[Name] IS NULL

	-- PARA TEMPLATES DE UN FORMATO, AGREGAMOS LAS QUERY_ID (INTENTS) DE LAS TIPIFICACIONES DE 1ER NIVEL
	IF @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	BEGIN
		INSERT INTO #TEMPLATE_MODELS 
			SELECT EFASTQ.[VCC],
					EF.[templateId],
					'',
					EFASTQ.[QueryId],
					EFASTQ.[QueryId],
					@TEMPLATE_TYPE,
					EFASTQ.[AcceptancePercentage],
					EFASTQ.[AcceptancePercentage] * 100, 
					NULL,
					NULL,
					NULL,
					NULL
				FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] EFASTQ (NOLOCK)
				INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
					ON EF.[Instance] = EFASTQ.[VCC]
						AND EF.[ID] = EFASTQ.[EvaluationFormatId]
				WHERE EF.[templateId] = @TemplateId

	END

	-- CONSULTAMOS EL TOTAL DE LA TABLA TEMPORAL
	SELECT * FROM #TEMPLATE_MODELS (NOLOCK)

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.7.0_database.tar.gz: database/mssql/procedures/GetTemplateThemeModels.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- exec [GetTemplateThemeModels] 'allegro','Test1234'
CREATE PROCEDURE [dbo].[GetTemplateThemeModels] (
	@VCC Varchar(50) = NULL, 
	@TemplateId Varchar(50) = NULL,
	@TemplateThemeId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA DETERMINAR SI ES UN FORMATO O PLANTILLA
	DECLARE @TEMPLATE_TYPE VARCHAR(50) = NULL

	-- BUSCAMOS POR EL ID SI SE TRATA DE UNA PLANTILLA O FORMATO
	IF EXISTS (
		SELECT 1 
			FROM [dbo].[Template] T (NOLOCK)
			INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = T.[VCC]
					AND EF.[templateId] = T.[Name]
			WHERE T.[VCC] = @VCC
				AND T.[Name] = @TemplateId
	)
		SET @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	ELSE 
		SET @TEMPLATE_TYPE = 'TEMPLATE'

	-- SELECCIONAMOS LOS ITEMS INMEDIATOS RELACIONADOS AL TEMPLATE
	SELECT DISTINCT A.[VCC]												'vcc',	
					A.[TemplateId]										'templateId',
					A.[TemplateThemeId]									'templateThemeId',
					A.[ID]												'id',
					-- CASE WHEN ISNULL(GQ.[Query],'') = ISNULL(NULL,'') THEN A.[ID] ELSE GQ.[Query] END	'query',
					--A.[ID]												'query',
					CASE WHEN @TEMPLATE_TYPE = 'EVALUATION_FORMAT' 
						THEN A.[ID]
						ELSE 
							CASE WHEN NI.[nluId] IS NOT NULL 
								THEN NI.[nluId] + '|' + NI.[intentId]
								ELSE A.[ID]
								END
						END												'query',
					TT.[AnalysisType]									'analysisType',
					@TEMPLATE_TYPE										'templateType',
					A.[AcceptancePercentage]							'acceptancePercentage',
					ISNULL(A.[AcceptancePercentage],0) * 100			'acceptanceInteger',
					A.[CreatedDate]										'createdDate',
					A.[CreatedByUserId]									'createdByUserId',
					A.[LastModifiedDate]								'lastModifiedDate',
					A.[LastModifiedByUserId]							'lastModifiedByUserId'
		INTO #TEMPLATE_MODELS 
		FROM [TemplateThemeItem] A (NOLOCK)
		INNER JOIN [dbo].[TemplateTheme] TT (NOLOCK)
			ON TT.[VCC] = A.[VCC]
				AND TT.[TemplateId] = A.[TemplateId]
				AND TT.[ID] = A.[TemplateThemeId]
		LEFT JOIN [dbo].[GenericQuery] GQ (NOLOCK) 
			ON A.[ID] = GQ.[Name] 
				AND A.[VCC] = GQ.[VCC]
		LEFT JOIN (
			SELECT DISTINCT
					INNER_N.[VCC]								'vcc'
					,INNER_N.[Name] + '|'+ INNER_I.[Name]		'cognitiveId'
					,INNER_N.[Name]								'nluId'
					,INNER_N.[AppId]							'appId'
					,INNER_I.[IntentId]							'intentId'
					,INNER_I.[Name]
				FROM [dbo].[NLU] INNER_N (NOLOCK)
				INNER JOIN [dbo].[Intent] INNER_I (NOLOCK) 
					ON INNER_N.[VCC] = INNER_I.[VCC]
						AND INNER_N.AppId = INNER_I.[AppId] 
				WHERE INNER_N.[VCC] = @VCC
		) NI 
			ON NI.[vcc] = A.[VCC]
				AND NI.[cognitiveId] = A.[ID]
		WHERE A.[VCC] = @VCC
			AND A.[TemplateId] = CASE WHEN ISNULL(@TemplateId, '') = '' THEN A.[TemplateId] ELSE @TemplateId END
			AND A.[TemplateThemeId] = CASE WHEN ISNULL(@TemplateThemeId, '') = '' THEN A.[TemplateThemeId] ELSE @TemplateThemeId END
			AND GQ.[Name] IS NULL

	-- PARA TEMPLATES DE UN FORMATO, AGREGAMOS LAS QUERY_ID (INTENTS) DE LAS TIPIFICACIONES DE 1ER NIVEL
	IF @TEMPLATE_TYPE = 'EVALUATION_FORMAT'
	BEGIN
		INSERT INTO #TEMPLATE_MODELS 
			SELECT DISTINCT EFASTQ.[VCC],
							EF.[templateId],
							'',
							EFASTQ.[QueryId],
							EFASTQ.[QueryId],
							A.[AnalysisType],
							@TEMPLATE_TYPE,
							EFASTQ.[AcceptancePercentage],
							EFASTQ.[AcceptancePercentage] * 100, 
							NULL,
							NULL,
							NULL,
							NULL
				FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] EFASTQ (NOLOCK)
				INNER JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
					ON EF.[Instance] = EFASTQ.[VCC]
						AND EF.[ID] = EFASTQ.[EvaluationFormatId]
				INNER JOIN [dbo].[Score] S (NOLOCK)
					ON S.[Instance] = EFASTQ.[VCC]
						AND S.[ID] = EFASTQ.[ScoreId]
				INNER JOIN [dbo].[Ability] A (NOLOCK)
					ON A.[Instance] = EFASTQ.[VCC]
						AND A.[ID] = S.[IdAbility]
				WHERE EFASTQ.[VCC] = @VCC
					AND EF.[templateId] = @TemplateId

	END
	--select * FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] EFASTQ (NOLOCK)
	--SELECT * FROM Score (NOLOCK)
	-- CONSULTAMOS EL TOTAL DE LA TABLA TEMPORAL
	SELECT * FROM #TEMPLATE_MODELS (NOLOCK)

	SET NOCOUNT OFF
END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
